@@ -3,10 +3,11 @@ from reversion.admin import VersionAdmin
 
 from armstrong.core.arm_content.admin import fieldsets
 from armstrong.core.arm_sections.admin import SectionTreeAdminMixin
+from armstrong import hatband
 from .models import Article
 
 
-class ArticleAdmin(SectionTreeAdminMixin, VersionAdmin):
+class ArticleAdmin(SectionTreeAdminMixin, VersionAdmin, hatband.ModelAdmin):
     fieldsets = (
         (None, {
             'fields': ('title', 'summary', 'body',
